==> ideaIC-211.7442.40-sources.jar: git4idea/ignore/lang/GitIgnoreLanguage.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2018 hsz Jakub Chrzanowski <jakub@hsz.mobi>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package git4idea.ignore.lang;

import com.intellij.openapi.vcs.changes.ignore.lang.IgnoreFileType;
import com.intellij.openapi.vcs.changes.ignore.lang.IgnoreLanguage;
import org.jetbrains.annotations.NotNull;

/**
 * Gitignore {@link IgnoreLanguage} definition.
 */
public final class GitIgnoreLanguage extends IgnoreLanguage {

  public static final GitIgnoreLanguage INSTANCE = new GitIgnoreLanguage();

  private GitIgnoreLanguage() {
    super("GitIgnore", "gitignore");
  }

  /**
   * Language file type.
   *
   * @return {@link GitIgnoreFileType} instance
   */
  @NotNull
  @Override
  public IgnoreFileType getFileType() {
    return GitIgnoreFileType.INSTANCE;
  }
}

==> ideaIC-2019.2-sources.jar: git4idea/ignore/lang/GitIgnoreLanguage.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2018 hsz Jakub Chrzanowski <jakub@hsz.mobi>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package git4idea.ignore.lang;

import com.intellij.icons.AllIcons;
import com.intellij.openapi.vcs.changes.ignore.lang.IgnoreFileType;
import com.intellij.openapi.vcs.changes.ignore.lang.IgnoreLanguage;
import org.jetbrains.annotations.NotNull;

/**
 * Gitignore {@link IgnoreLanguage} definition.
 */
public class GitIgnoreLanguage extends IgnoreLanguage {

  public static final GitIgnoreLanguage INSTANCE = new GitIgnoreLanguage();

  private GitIgnoreLanguage() {
    super("GitIgnore", "gitignore");
  }

  /**
   * Language file type.
   *
   * @return {@link GitIgnoreFileType} instance
   */
  @NotNull
  @Override
  public IgnoreFileType getFileType() {
    return GitIgnoreFileType.INSTANCE;
  }
}
